==> mcu_plus_sdk_am261x_11_00_00_29_docs_only.tar.xz: mcu_plus_sdk_am261x_11_00_00_29_docs_only/docs/api_guide_am261x/RELEASE_NOTES_PAGE.js <==
var RELEASE_NOTES_PAGE =
[
    [ "Release Notes 11.00.00", "RELEASE_NOTES_11_00_00_PAGE.html", [
      [ "New in this Release", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md133", null ],
      [ "Modules Not tested/supported in this release", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md134", [
        [ "Device and Validation Information", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md135", null ],
        [ "Dependent Tools and Compiler Information", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md136", null ],
        [ "Key Features", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md137", [
          [ "Experimental Features", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md138", null ],
          [ "OS Kernel", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md139", null ],
          [ "Driver Porting Layer (DPL)", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md140", null ],
          [ "Secondary Bootloader (SBL)", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md141", null ],
          [ "SOC Device Drivers", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md142", null ],
          [ "Trigonometric Operations", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md143", null ],
          [ "Board Device Drivers", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md144", null ],
          [ "Networking", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md145", null ],
          [ "Safety Diagnostic Library", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md146", null ]
        ] ],
        [ "Fixed Issues", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md147", null ],
        [ "Known Issues", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md148", null ],
        [ "Errata", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md149", null ],
        [ "Limitations", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md150", null ],
        [ "Upgrade and Compatibility Information", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md151", [
          [ "LP / SOM Rev E2 to Rev A revision Changes", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md152", null ],
          [ "Migration to 400 MHz in ZFG package", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md153", null ],
          [ "Compiling examples in MacOS machines", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md154", null ],
          [ "RPRC Image format is Deprecated and Corresponding SBL's are also removed from SDK", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md155", null ],
          [ "Flash Reset moved to SysCfg", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md156", null ],
          [ "Module clock configuration through Clock Tree", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md157", null ],
          [ "Migrating back from CCS Theia to CCS Eclipse", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md158", [
            [ "Importing and Building in Eclipse", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md159", null ],
            [ "CCS SBL Loading", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md160", null ]
          ] ],
          [ "Migrating examples to 11.00.00 from older versions", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md161", [
            [ "Makefile Changes", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md162", null ]
          ] ],
          [ "SDL PBIST Self test", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md165", null ],
          [ "Compiler Options", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md166", null ],
          [ "SOC Device Drivers", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md167", null ],
          [ "Networking", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md168", null ]
        ] ]
      ] ]
    ] ],
    [ "Release Notes 10.02.00", "RELEASE_NOTES_10_02_00_PAGE.html", [
      [ "New in this Release", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md108", null ],
      [ "Modules Not tested/supported in this release", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md109", [
        [ "Device and Validation Information", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md110", null ],
        [ "Dependent Tools and Compiler Information", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md111", null ],
        [ "Key Features", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md112", [
          [ "Experimental Features", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md113", null ],
          [ "OS Kernel", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md114", null ],
          [ "Driver Porting Layer (DPL)", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md115", null ],
          [ "Secondary Bootloader (SBL)", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md116", null ],
          [ "SOC Device Drivers", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md117", null ],
          [ "Trigonometric Operations", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md118", null ],
          [ "Board Device Drivers", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md119", null ],
          [ "Networking", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md120", null ],
          [ "Safety Diagnostic Library", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md121", null ]
        ] ],
        [ "Fixed Issues", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md122", null ],
        [ "Known Issues", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md123", null ],
        [ "Errata", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md124", null ],
        [ "Limitations", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md125", null ],
        [ "Upgrade and Compatibility Information", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md126", [
          [ "Flash Migration in AM261x-LP : E2 to E1", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md127", null ],
          [ "How to run FOTA examples on AM261x-LP-E1 board", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md128", null ],
          [ "Changes in FLSOPSKD and FOTAAgent driver", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md129", null ],
          [ "Compiler Options", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md130", null ],
          [ "SOC Device Drivers", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md131", null ],
          [ "Networking", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md132", null ]
        ] ]
      ] ]
    ] ],
    [ "Release Notes 10.00.01", "RELEASE_NOTES_10_00_01_PAGE.html", [
      [ "New in this Release", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md87", null ],
      [ "Modules Not tested/supported in this release", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md88", [
        [ "Device and Validation Information", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md89", null ],
        [ "Dependent Tools and Compiler Information", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md90", null ],
        [ "Key Features", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md91", [
          [ "Experimental Features", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md92", null ],
          [ "OS Kernel", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md93", null ],
          [ "Driver Porting Layer (DPL)", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md94", null ],
          [ "Secondary Bootloader (SBL)", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md95", null ],
          [ "SOC Device Drivers", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md96", null ],
          [ "Trigonometric Operations", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md97", null ],
          [ "Board Device Drivers", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md98", null ],
          [ "Networking", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md99", null ]
        ] ],
        [ "Fixed Issues", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md100", null ],
        [ "Known Issues", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md101", null ],
        [ "Errata", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md102", null ],
        [ "Limitations", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md103", null ],
        [ "Upgrade and Compatibility Information", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md104", [
          [ "Compiler Options", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md105", null ],
          [ "SOC Device Drivers", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md106", null ],
          [ "Networking", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md107", null ]
        ] ]
      ] ]
    ] ],
    [ "Release Notes 10.00.00", "RELEASE_NOTES_10_00_00_PAGE.html", [
      [ "New in this Release", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md66", null ],
      [ "Modules Not tested/supported in this release", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md67", [
        [ "Device and Validation Information", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md68", null ],
        [ "Dependent Tools and Compiler Information", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md69", null ],
        [ "Key Features", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md70", [
          [ "Experimental Features", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md71", null ],
          [ "OS Kernel", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md72", null ],
          [ "Driver Porting Layer (DPL)", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md73", null ],
          [ "Secondary Bootloader (SBL)", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md74", null ],
          [ "SOC Device Drivers", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md75", null ],
          [ "Trigonometric Operations", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md76", null ],
          [ "Board Device Drivers", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md77", null ],
          [ "Networking", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md78", null ]
        ] ],
        [ "Fixed Issues", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md79", null ],
        [ "Known Issues", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md80", null ],
        [ "Errata", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md81", null ],
        [ "Limitations", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md82", null ],
        [ "Upgrade and Compatibility Information", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md83", [
          [ "Compiler Options", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md84", null ],
          [ "SOC Device Drivers", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md85", null ],
          [ "Networking", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md86", null ]
        ] ]
      ] ]
    ] ]
];

==> mcu_plus_sdk_am261x_11_01_00_19_docs_only.tar.xz: mcu_plus_sdk_am261x_11_01_00_19_docs_only/docs/api_guide_am261x/RELEASE_NOTES_PAGE.js <==
var RELEASE_NOTES_PAGE =
[
    [ "Release Notes 11.01.00", "RELEASE_NOTES_11_01_00_PAGE.html", [
      [ "New in this Release", "RELEASE_NOTES_11_01_00_PAGE.html#autotoc_md169", null ],
      [ "Modules Not tested/supported in this release", "RELEASE_NOTES_11_01_00_PAGE.html#autotoc_md170", [
        [ "Device and Validation Information", "RELEASE_NOTES_11_01_00_PAGE.html#autotoc_md171", null ],
        [ "Dependent Tools and Compiler Information", "RELEASE_NOTES_11_01_00_PAGE.html#autotoc_md172", null ],
        [ "Key Features", "RELEASE_NOTES_11_01_00_PAGE.html#autotoc_md173", [
          [ "Experimental Features", "RELEASE_NOTES_11_01_00_PAGE.html#autotoc_md174", null ],
          [ "OS Kernel", "RELEASE_NOTES_11_01_00_PAGE.html#autotoc_md175", null ],
          [ "Driver Porting Layer (DPL)", "RELEASE_NOTES_11_01_00_PAGE.html#autotoc_md176", null ],
          [ "Secondary Bootloader (SBL)", "RELEASE_NOTES_11_01_00_PAGE.html#autotoc_md177", null ],
          [ "SOC Device Drivers", "RELEASE_NOTES_11_01_00_PAGE.html#autotoc_md178", null ],
          [ "Trigonometric Operations", "RELEASE_NOTES_11_01_00_PAGE.html#autotoc_md179", null ],
          [ "Board Device Drivers", "RELEASE_NOTES_11_01_00_PAGE.html#autotoc_md180", null ],
          [ "Networking", "RELEASE_NOTES_11_01_00_PAGE.html#autotoc_md181", null ],
          [ "Safety Diagnostic Library", "RELEASE_NOTES_11_01_00_PAGE.html#autotoc_md182", null ]
        ] ],
        [ "Fixed Issues", "RELEASE_NOTES_11_01_00_PAGE.html#autotoc_md183", null ],
        [ "Known Issues", "RELEASE_NOTES_11_01_00_PAGE.html#autotoc_md184", null ],
        [ "Errata", "RELEASE_NOTES_11_01_00_PAGE.html#autotoc_md185", null ],
        [ "Limitations", "RELEASE_NOTES_11_01_00_PAGE.html#autotoc_md186", null ],
        [ "Upgrade and Compatibility Information", "RELEASE_NOTES_11_01_00_PAGE.html#autotoc_md187", [
          [ "LP / SOM Rev E2 to Rev A revision Changes", "RELEASE_NOTES_11_01_00_PAGE.html#autotoc_md188", null ],
          [ "Migration to 400 MHz in ZFG package", "RELEASE_NOTES_11_01_00_PAGE.html#autotoc_md189", null ],
          [ "Compiling examples in MacOS machines", "RELEASE_NOTES_11_01_00_PAGE.html#autotoc_md190", null ],
          [ "RPRC Image format is Deprecated and Corresponding SBL's are also removed from SDK", "RELEASE_NOTES_11_01_00_PAGE.html#autotoc_md191", null ],
          [ "Flash Reset moved to SysCfg", "RELEASE_NOTES_11_01_00_PAGE.html#autotoc_md192", null ],
          [ "Module clock configuration through Clock Tree", "RELEASE_NOTES_11_01_00_PAGE.html#autotoc_md193", null ],
          [ "Migrating back from CCS Theia to CCS Eclipse", "RELEASE_NOTES_11_01_00_PAGE.html#autotoc_md194", [
            [ "Importing and Building in Eclipse", "RELEASE_NOTES_11_01_00_PAGE.html#autotoc_md195", null ],
            [ "CCS SBL Loading", "RELEASE_NOTES_11_01_00_PAGE.html#autotoc_md196", null ]
          ] ],
          [ "Migrating examples to 11.00.00 from older versions", "RELEASE_NOTES_11_01_00_PAGE.html#autotoc_md197", [
            [ "Makefile Changes", "RELEASE_NOTES_11_01_00_PAGE.html#autotoc_md198", null ]
          ] ],
          [ "SDL PBIST Self test", "RELEASE_NOTES_11_01_00_PAGE.html#autotoc_md201", null ],
          [ "SDL STC Configuration", "RELEASE_NOTES_11_01_00_PAGE.html#autotoc_md202", null ],
          [ "SDL Handler API name update", "RELEASE_NOTES_11_01_00_PAGE.html#autotoc_md203", null ],
          [ "Compiler Options", "RELEASE_NOTES_11_01_00_PAGE.html#autotoc_md204", null ],
          [ "SOC Device Drivers", "RELEASE_NOTES_11_01_00_PAGE.html#autotoc_md205", null ],
          [ "Networking", "RELEASE_NOTES_11_01_00_PAGE.html#autotoc_md206", null ]
        ] ]
      ] ]
    ] ],
    [ "Release Notes 11.00.00", "RELEASE_NOTES_11_00_00_PAGE.html", [
      [ "New in this Release", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md133", null ],
      [ "Modules Not tested/supported in this release", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md134", [
        [ "Device and Validation Information", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md135", null ],
        [ "Dependent Tools and Compiler Information", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md136", null ],
        [ "Key Features", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md137", [
          [ "Experimental Features", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md138", null ],
          [ "OS Kernel", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md139", null ],
          [ "Driver Porting Layer (DPL)", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md140", null ],
          [ "Secondary Bootloader (SBL)", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md141", null ],
          [ "SOC Device Drivers", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md142", null ],
          [ "Trigonometric Operations", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md143", null ],
          [ "Board Device Drivers", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md144", null ],
          [ "Networking", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md145", null ],
          [ "Safety Diagnostic Library", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md146", null ]
        ] ],
        [ "Fixed Issues", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md147", null ],
        [ "Known Issues", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md148", null ],
        [ "Errata", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md149", null ],
        [ "Limitations", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md150", null ],
        [ "Upgrade and Compatibility Information", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md151", [
          [ "LP / SOM Rev E2 to Rev A revision Changes", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md152", null ],
          [ "Migration to 400 MHz in ZFG package", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md153", null ],
          [ "Compiling examples in MacOS machines", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md154", null ],
          [ "RPRC Image format is Deprecated and Corresponding SBL's are also removed from SDK", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md155", null ],
          [ "Flash Reset moved to SysCfg", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md156", null ],
          [ "Module clock configuration through Clock Tree", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md157", null ],
          [ "Migrating back from CCS Theia to CCS Eclipse", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md158", [
            [ "Importing and Building in Eclipse", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md159", null ],
            [ "CCS SBL Loading", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md160", null ]
          ] ],
          [ "Migrating examples to 11.00.00 from older versions", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md161", [
            [ "Makefile Changes", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md162", null ]
          ] ],
          [ "SDL PBIST Self test", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md165", null ],
          [ "Compiler Options", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md166", null ],
          [ "SOC Device Drivers", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md167", null ],
          [ "Networking", "RELEASE_NOTES_11_00_00_PAGE.html#autotoc_md168", null ]
        ] ]
      ] ]
    ] ],
    [ "Release Notes 10.02.00", "RELEASE_NOTES_10_02_00_PAGE.html", [
      [ "New in this Release", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md108", null ],
      [ "Modules Not tested/supported in this release", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md109", [
        [ "Device and Validation Information", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md110", null ],
        [ "Dependent Tools and Compiler Information", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md111", null ],
        [ "Key Features", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md112", [
          [ "Experimental Features", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md113", null ],
          [ "OS Kernel", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md114", null ],
          [ "Driver Porting Layer (DPL)", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md115", null ],
          [ "Secondary Bootloader (SBL)", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md116", null ],
          [ "SOC Device Drivers", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md117", null ],
          [ "Trigonometric Operations", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md118", null ],
          [ "Board Device Drivers", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md119", null ],
          [ "Networking", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md120", null ],
          [ "Safety Diagnostic Library", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md121", null ]
        ] ],
        [ "Fixed Issues", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md122", null ],
        [ "Known Issues", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md123", null ],
        [ "Errata", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md124", null ],
        [ "Limitations", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md125", null ],
        [ "Upgrade and Compatibility Information", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md126", [
          [ "Flash Migration in AM261x-LP : E2 to E1", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md127", null ],
          [ "How to run FOTA examples on AM261x-LP-E1 board", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md128", null ],
          [ "Changes in FLSOPSKD and FOTAAgent driver", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md129", null ],
          [ "Compiler Options", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md130", null ],
          [ "SOC Device Drivers", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md131", null ],
          [ "Networking", "RELEASE_NOTES_10_02_00_PAGE.html#autotoc_md132", null ]
        ] ]
      ] ]
    ] ],
    [ "Release Notes 10.00.01", "RELEASE_NOTES_10_00_01_PAGE.html", [
      [ "New in this Release", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md87", null ],
      [ "Modules Not tested/supported in this release", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md88", [
        [ "Device and Validation Information", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md89", null ],
        [ "Dependent Tools and Compiler Information", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md90", null ],
        [ "Key Features", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md91", [
          [ "Experimental Features", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md92", null ],
          [ "OS Kernel", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md93", null ],
          [ "Driver Porting Layer (DPL)", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md94", null ],
          [ "Secondary Bootloader (SBL)", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md95", null ],
          [ "SOC Device Drivers", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md96", null ],
          [ "Trigonometric Operations", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md97", null ],
          [ "Board Device Drivers", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md98", null ],
          [ "Networking", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md99", null ]
        ] ],
        [ "Fixed Issues", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md100", null ],
        [ "Known Issues", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md101", null ],
        [ "Errata", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md102", null ],
        [ "Limitations", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md103", null ],
        [ "Upgrade and Compatibility Information", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md104", [
          [ "Compiler Options", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md105", null ],
          [ "SOC Device Drivers", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md106", null ],
          [ "Networking", "RELEASE_NOTES_10_00_01_PAGE.html#autotoc_md107", null ]
        ] ]
      ] ]
    ] ],
    [ "Release Notes 10.00.00", "RELEASE_NOTES_10_00_00_PAGE.html", [
      [ "New in this Release", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md66", null ],
      [ "Modules Not tested/supported in this release", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md67", [
        [ "Device and Validation Information", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md68", null ],
        [ "Dependent Tools and Compiler Information", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md69", null ],
        [ "Key Features", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md70", [
          [ "Experimental Features", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md71", null ],
          [ "OS Kernel", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md72", null ],
          [ "Driver Porting Layer (DPL)", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md73", null ],
          [ "Secondary Bootloader (SBL)", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md74", null ],
          [ "SOC Device Drivers", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md75", null ],
          [ "Trigonometric Operations", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md76", null ],
          [ "Board Device Drivers", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md77", null ],
          [ "Networking", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md78", null ]
        ] ],
        [ "Fixed Issues", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md79", null ],
        [ "Known Issues", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md80", null ],
        [ "Errata", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md81", null ],
        [ "Limitations", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md82", null ],
        [ "Upgrade and Compatibility Information", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md83", [
          [ "Compiler Options", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md84", null ],
          [ "SOC Device Drivers", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md85", null ],
          [ "Networking", "RELEASE_NOTES_10_00_00_PAGE.html#autotoc_md86", null ]
        ] ]
      ] ]
    ] ]
];
